@@ -45,9 +45,9 @@ build_time_vars = {'ABIFLAGS': '',
                 "'--host=powerpc64-unknown-linux-gnu' "
                 "'--mandir=/usr/share/man' '--infodir=/usr/share/info' "
                 "'--datadir=/usr/share' '--sysconfdir=/etc' "
-                "'--localstatedir=/var/lib' "
-                "'--docdir=/usr/share/doc/python-3.11.7' "
-                "'--htmldir=/usr/share/doc/python-3.11.7/html' "
+                "'--localstatedir=/var/lib' '--datarootdir=/usr/share' "
+                "'--docdir=/usr/share/doc/python-3.11.8_p1' "
+                "'--htmldir=/usr/share/doc/python-3.11.8_p1/html' "
                 "'--libdir=/usr/lib64' 'ac_cv_header_stropts_h=no' "
                 "'--enable-shared' '--without-static-libpython' "
                 "'--enable-ipv6' '--infodir=/usr/share/info' "
@@ -66,9 +66,9 @@ build_time_vars = {'ABIFLAGS': '',
  'CONFINCLUDEDIR': '/usr/include',
  'CONFINCLUDEPY': '/usr/include/python3.11',
  'COREPYTHONPATH': '',
- 'COVERAGE_INFO': '/var/tmp/portage/dev-lang/python-3.11.7/work/Python-3.11.7/coverage.info',
+ 'COVERAGE_INFO': '/var/tmp/portage/dev-lang/python-3.11.8_p1/work/Python-3.11.8/coverage.info',
  'COVERAGE_LCOV_OPTIONS': '--rc lcov_branch_coverage=1',
- 'COVERAGE_REPORT': '/var/tmp/portage/dev-lang/python-3.11.7/work/Python-3.11.7/lcov-report',
+ 'COVERAGE_REPORT': '/var/tmp/portage/dev-lang/python-3.11.8_p1/work/Python-3.11.8/lcov-report',
  'COVERAGE_REPORT_OPTIONS': '--rc lcov_branch_coverage=1 --branch-coverage '
                             '--title "CPython 3.11 LCOV report [commit $(shell '
                             ')]"',
@@ -143,7 +143,7 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_BLUETOOTH_BLUETOOTH_H': 0,
  'HAVE_BLUETOOTH_H': 0,
  'HAVE_BROKEN_MBSTOWCS': 0,
- 'HAVE_BROKEN_NICE': 0,
+ 'HAVE_BROKEN_NICE': 1,
  'HAVE_BROKEN_PIPE_BUF': 0,
  'HAVE_BROKEN_POLL': 0,
  'HAVE_BROKEN_POSIX_SEMAPHORES': 0,
@@ -988,7 +988,7 @@ build_time_vars = {'ABIFLAGS': '',
  'READELF': 'powerpc64-unknown-linux-gnu-readelf',
  'RESSRCDIR': 'Mac/Resources/framework',
  'RETSIGTYPE': 'void',
- 'RUNSHARED': 'LD_LIBRARY_PATH=/var/tmp/portage/dev-lang/python-3.11.7/work/Python-3.11.7',
+ 'RUNSHARED': 'LD_LIBRARY_PATH=/var/tmp/portage/dev-lang/python-3.11.8_p1/work/Python-3.11.8',
  'SCRIPTDIR': '/usr/lib',
  'SETPGRP_HAVE_ARG': 0,
  'SHELL': '/bin/sh',
@@ -1032,10 +1032,10 @@ build_time_vars = {'ABIFLAGS': '',
  'SYS_SELECT_WITH_SYS_TIME': 1,
  'TESTOPTS': '',
  'TESTPATH': '',
- 'TESTPYTHON': 'LD_LIBRARY_PATH=/var/tmp/portage/dev-lang/python-3.11.7/work/Python-3.11.7 '
+ 'TESTPYTHON': 'LD_LIBRARY_PATH=/var/tmp/portage/dev-lang/python-3.11.8_p1/work/Python-3.11.8 '
                './python -E',
  'TESTPYTHONOPTS': '',
- 'TESTRUNNER': 'LD_LIBRARY_PATH=/var/tmp/portage/dev-lang/python-3.11.7/work/Python-3.11.7 '
+ 'TESTRUNNER': 'LD_LIBRARY_PATH=/var/tmp/portage/dev-lang/python-3.11.8_p1/work/Python-3.11.8 '
                './python -E ./Tools/scripts/run_tests.py',
  'TESTSUBDIRS': 'ctypes/test \\',
  'TESTTIMEOUT': 1200,
@@ -1066,8 +1066,8 @@ build_time_vars = {'ABIFLAGS': '',
  'WITH_VALGRIND': 0,
  'X87_DOUBLE_ROUNDING': 0,
  'XMLLIBSUBDIRS': 'xml xml/dom xml/etree xml/parsers xml/sax',
- 'abs_builddir': '/var/tmp/portage/dev-lang/python-3.11.7/work/Python-3.11.7',
- 'abs_srcdir': '/var/tmp/portage/dev-lang/python-3.11.7/work/Python-3.11.7',
+ 'abs_builddir': '/var/tmp/portage/dev-lang/python-3.11.8_p1/work/Python-3.11.8',
+ 'abs_srcdir': '/var/tmp/portage/dev-lang/python-3.11.8_p1/work/Python-3.11.8',
  'datarootdir': '/usr/share',
  'exec_prefix': '/usr',
  'prefix': '/usr',
