@@ -7,82 +7,73 @@ build_time_vars = {'ABIFLAGS': '',
  'ALIGNOF_SIZE_T': 8,
  'ALT_SOABI': 0,
  'ANDROID_API_LEVEL': 0,
- 'AR': '/usr/lib/llvm/17/bin/llvm-ar',
+ 'AR': 'x86_64-pc-linux-gnu-ar',
  'ARFLAGS': 'rcs',
- 'BASECFLAGS': '-Wsign-compare -Wunreachable-code',
+ 'BASECFLAGS': '-Wsign-compare',
  'BASECPPFLAGS': '',
  'BASEMODLIBS': '',
  'BINDIR': '/usr/bin',
  'BINLIBDEST': '/usr/lib/python3.11',
  'BLDLIBRARY': '-L. -lpython3.11',
- 'BLDSHARED': 'clang -shared',
+ 'BLDSHARED': 'x86_64-pc-linux-gnu-gcc -shared',
  'BOOTSTRAP_HEADERS': '\\',
  'BUILDEXE': '',
  'BUILDPYTHON': 'python',
  'BUILD_GNU_TYPE': 'x86_64-pc-linux-gnu',
  'BYTESTR_DEPS': '\\',
- 'CC': 'clang',
+ 'CC': 'x86_64-pc-linux-gnu-gcc',
  'CCSHARED': '-fPIC',
- 'CFLAGS': '-Wsign-compare -Wunreachable-code -DNDEBUG',
+ 'CFLAGS': '-Wsign-compare -DNDEBUG',
  'CFLAGSFORSHARED': '-fPIC',
  'CFLAGS_ALIASING': '',
+ 'CFLAGS_NODIST': '',
  'CONFIGFILES': 'configure configure.ac acconfig.h pyconfig.h.in '
                 'Makefile.pre.in',
  'CONFIGURE_CFLAGS': '',
  'CONFIGURE_CFLAGS_NODIST': '-O3 -pipe -march=znver2 -mtune=znver3 '
-                            '-fpermissive -frecord-gcc-switches '
-                            '-fdiagnostics-color=never '
-                            '-Wno-error=implicit-function-declaration '
-                            '-flto=thin -Wno-cflagsver0010 -fwrapv -flto -g '
-                            '-std=c11 -Wextra -Wno-unused-parameter '
+                            '-frecord-gcc-switches -fdiagnostics-color=never '
+                            '-fwrapv -std=c11 -Wextra -Wno-unused-parameter '
                             '-Wno-missing-field-initializers '
                             '-Wstrict-prototypes '
                             '-Werror=implicit-function-declaration '
                             '-fvisibility=hidden',
  'CONFIGURE_CPPFLAGS': '-I/usr/include/ncursesw',
  'CONFIGURE_LDFLAGS': '',
- 'CONFIGURE_LDFLAGS_NODIST': '-v -Wl,-O1 -Wl,--as-needed -Wl,--as-needed '
-                             '-Wl,-O2 -Wl,--as-needed '
-                             '-Wl,-z,pack-relative-relocs -Wl,-z,relro '
-                             '-Wl,-z,now -flto -g',
- 'CONFIGURE_LDFLAGS_NOLTO': '-flto=thin',
+ 'CONFIGURE_LDFLAGS_NODIST': '-Wl,-O1 -Wl,--as-needed '
+                             '-Wl,-z,pack-relative-relocs',
+ 'CONFIGURE_LDFLAGS_NOLTO': '',
  'CONFIG_ARGS': "'--prefix=/usr' '--build=x86_64-pc-linux-gnu' "
                 "'--host=x86_64-pc-linux-gnu' '--mandir=/usr/share/man' "
                 "'--infodir=/usr/share/info' '--datadir=/usr/share' "
                 "'--sysconfdir=/etc' '--localstatedir=/var/lib' "
-                "'--docdir=/usr/share/doc/python-3.11.7' "
-                "'--htmldir=/usr/share/doc/python-3.11.7/html' "
+                "'--docdir=/usr/share/doc/python-3.11.8' "
+                "'--htmldir=/usr/share/doc/python-3.11.8/html' "
                 "'--libdir=/usr/lib64' 'ac_cv_header_stropts_h=no' "
                 "'--enable-shared' '--without-static-libpython' "
                 "'--enable-ipv6' '--infodir=/usr/share/info' "
                 "'--mandir=/usr/share/man' '--with-computed-gotos' "
-                "'--with-dbmliborder=' '--with-libc=' "
+                "'--with-dbmliborder=gdbm' '--with-libc=' "
                 "'--enable-loadable-sqlite-extensions' '--without-ensurepip' "
                 "'--without-lto' '--with-system-expat' '--with-system-ffi' "
                 "'--with-platlibdir=lib' '--with-pkg-config=yes' "
                 "'--with-wheel-pkg-dir=/usr/lib/python/ensurepip' "
-                "'--without-assertions' '--enable-optimizations' "
-                "'--with-readline=readline' '--without-valgrind' '--with-lto' "
+                "'--without-assertions' '--disable-optimizations' "
+                "'--with-readline=readline' '--without-valgrind' "
                 "'build_alias=x86_64-pc-linux-gnu' "
                 "'host_alias=x86_64-pc-linux-gnu' "
-                "'PKG_CONFIG=x86_64-pc-linux-gnu-pkg-config' 'CC=clang' "
-                "'CFLAGS=' 'LDFLAGS=' 'CPPFLAGS= -I/usr/include/ncursesw' "
-                "'CPP=clang-cpp' 'PROFILE_TASK=-m test -j24 --pgo-extended "
-                '-u-network --timeout 1200 -x test_gdb -x test_dtrace -x '
-                'test_asyncio -x test_httpservers -x test_logging -x '
-                'test_multiprocessing_fork -x test_socket -x test_xmlrpc -x '
-                "test_tools'",
+                "'PKG_CONFIG=x86_64-pc-linux-gnu-pkg-config' 'CFLAGS=' "
+                "'LDFLAGS=' 'CPPFLAGS= -I/usr/include/ncursesw'",
  'CONFINCLUDEDIR': '/usr/include',
  'CONFINCLUDEPY': '/usr/include/python3.11',
  'COREPYTHONPATH': '',
- 'COVERAGE_INFO': '/var/tmp/portage/dev-lang/python-3.11.7/work/Python-3.11.7/coverage.info',
+ 'COVERAGE_INFO': '/var/tmp/portage/dev-lang/python-3.11.8/work/Python-3.11.8/coverage.info',
  'COVERAGE_LCOV_OPTIONS': '--rc lcov_branch_coverage=1',
- 'COVERAGE_REPORT': '/var/tmp/portage/dev-lang/python-3.11.7/work/Python-3.11.7/lcov-report',
+ 'COVERAGE_REPORT': '/var/tmp/portage/dev-lang/python-3.11.8/work/Python-3.11.8/lcov-report',
  'COVERAGE_REPORT_OPTIONS': '--rc lcov_branch_coverage=1 --branch-coverage '
                             '--title "CPython 3.11 LCOV report [commit $(shell '
                             ')]"',
  'CPPFLAGS': '-I. -I./Include -I/usr/include/ncursesw',
- 'CXX': 'clang++',
+ 'CXX': 'x86_64-pc-linux-gnu-g++',
  'DECIMAL_CFLAGS': '-I./Modules/_decimal/libmpdec -DCONFIG_64=1 -DANSI=1 '
                    '-DHAVE_UINT128_T=1',
  'DECIMAL_LDFLAGS': '-lm Modules/_decimal/libmpdec/libmpdec.a',
@@ -262,7 +253,7 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_GCC_UINT128_T': 1,
  'HAVE_GDBM_DASH_NDBM_H': 0,
  'HAVE_GDBM_H': 1,
- 'HAVE_GDBM_NDBM_H': 0,
+ 'HAVE_GDBM_NDBM_H': 1,
  'HAVE_GETADDRINFO': 1,
  'HAVE_GETC_UNLOCKED': 1,
  'HAVE_GETEGID': 1,
@@ -335,7 +326,7 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_LIBDB': 0,
  'HAVE_LIBDL': 1,
  'HAVE_LIBDLD': 0,
- 'HAVE_LIBGDBM_COMPAT': 0,
+ 'HAVE_LIBGDBM_COMPAT': 1,
  'HAVE_LIBIEEE': 0,
  'HAVE_LIBINTL_H': 1,
  'HAVE_LIBNDBM': 0,
@@ -623,38 +614,36 @@ build_time_vars = {'ABIFLAGS': '',
                    '/usr/include/python3.11',
  'INCLUDEDIR': '/usr/include',
  'INCLUDEPY': '/usr/include/python3.11',
- 'INSTALL': '/var/tmp/portage/._portage_reinstall_.w_l7c5xx/bin/ebuild-helpers/xattr/install '
+ 'INSTALL': '/var/tmp/portage/._portage_reinstall_.o0ixbqx6/bin/ebuild-helpers/xattr/install '
             '-c',
- 'INSTALL_DATA': '/var/tmp/portage/._portage_reinstall_.w_l7c5xx/bin/ebuild-helpers/xattr/install '
+ 'INSTALL_DATA': '/var/tmp/portage/._portage_reinstall_.o0ixbqx6/bin/ebuild-helpers/xattr/install '
                  '-c -m 644',
- 'INSTALL_PROGRAM': '/var/tmp/portage/._portage_reinstall_.w_l7c5xx/bin/ebuild-helpers/xattr/install '
+ 'INSTALL_PROGRAM': '/var/tmp/portage/._portage_reinstall_.o0ixbqx6/bin/ebuild-helpers/xattr/install '
                     '-c',
- 'INSTALL_SCRIPT': '/var/tmp/portage/._portage_reinstall_.w_l7c5xx/bin/ebuild-helpers/xattr/install '
+ 'INSTALL_SCRIPT': '/var/tmp/portage/._portage_reinstall_.o0ixbqx6/bin/ebuild-helpers/xattr/install '
                    '-c',
- 'INSTALL_SHARED': '/var/tmp/portage/._portage_reinstall_.w_l7c5xx/bin/ebuild-helpers/xattr/install '
+ 'INSTALL_SHARED': '/var/tmp/portage/._portage_reinstall_.o0ixbqx6/bin/ebuild-helpers/xattr/install '
                    '-c -m 755',
  'INSTSONAME': 'libpython3.11.so.1.0',
  'IO_H': 'Modules/_io/_iomodule.h',
  'IO_OBJS': '\\',
- 'LDCXXSHARED': 'clang++ -shared',
+ 'LDCXXSHARED': 'x86_64-pc-linux-gnu-g++ -shared',
  'LDFLAGS': '',
+ 'LDFLAGS_NODIST': '',
  'LDLIBRARY': 'libpython3.11.so',
  'LDLIBRARYDIR': '',
- 'LDSHARED': 'clang -shared',
+ 'LDSHARED': 'x86_64-pc-linux-gnu-gcc -shared',
  'LDVERSION': '3.11',
  'LIBC': '',
  'LIBDEST': '/usr/lib/python3.11',
  'LIBDIR': '/usr/lib64',
  'LIBEXPAT_A': 'Modules/expat/libexpat.a',
- 'LIBEXPAT_CFLAGS': '-Wsign-compare -Wunreachable-code -DNDEBUG -O3 -pipe '
-                    '-march=znver2 -mtune=znver3 -fpermissive '
-                    '-frecord-gcc-switches -fdiagnostics-color=never '
-                    '-Wno-error=implicit-function-declaration -flto=thin '
-                    '-Wno-cflagsver0010 -fwrapv -flto -g -std=c11 -Wextra '
+ 'LIBEXPAT_CFLAGS': '-Wsign-compare -DNDEBUG -O3 -pipe -march=znver2 '
+                    '-mtune=znver3 -frecord-gcc-switches '
+                    '-fdiagnostics-color=never -fwrapv -std=c11 -Wextra '
                     '-Wno-unused-parameter -Wno-missing-field-initializers '
                     '-Wstrict-prototypes -Werror=implicit-function-declaration '
-                    '-fvisibility=hidden -fprofile-instr-use=code.profclangd '
-                    '-I./Include/internal -I. -I./Include '
+                    '-fvisibility=hidden  -I./Include/internal -I. -I./Include '
                     '-I/usr/include/ncursesw -fPIC -fPIC',
  'LIBEXPAT_HEADERS': '\\',
  'LIBEXPAT_OBJS': '\\',
@@ -662,16 +651,12 @@ build_time_vars = {'ABIFLAGS': '',
  'LIBM': '-lm',
  'LIBMPDEC_A': 'Modules/_decimal/libmpdec/libmpdec.a',
  'LIBMPDEC_CFLAGS': '-I./Modules/_decimal/libmpdec -DCONFIG_64=1 -DANSI=1 '
-                    '-DHAVE_UINT128_T=1 -Wsign-compare -Wunreachable-code '
-                    '-DNDEBUG -O3 -pipe -march=znver2 -mtune=znver3 '
-                    '-fpermissive -frecord-gcc-switches '
-                    '-fdiagnostics-color=never '
-                    '-Wno-error=implicit-function-declaration -flto=thin '
-                    '-Wno-cflagsver0010 -fwrapv -flto -g -std=c11 -Wextra '
+                    '-DHAVE_UINT128_T=1 -Wsign-compare -DNDEBUG -O3 -pipe '
+                    '-march=znver2 -mtune=znver3 -frecord-gcc-switches '
+                    '-fdiagnostics-color=never -fwrapv -std=c11 -Wextra '
                     '-Wno-unused-parameter -Wno-missing-field-initializers '
                     '-Wstrict-prototypes -Werror=implicit-function-declaration '
-                    '-fvisibility=hidden -fprofile-instr-use=code.profclangd '
-                    '-I./Include/internal -I. -I./Include '
+                    '-fvisibility=hidden  -I./Include/internal -I. -I./Include '
                     '-I/usr/include/ncursesw -fPIC -fPIC',
  'LIBMPDEC_HEADERS': '\\',
  'LIBMPDEC_OBJS': '\\',
@@ -686,28 +671,27 @@ build_time_vars = {'ABIFLAGS': '',
  'LIBRARY_OBJS_OMIT_FROZEN': '\\',
  'LIBS': '-ldl',
  'LIBSUBDIRS': 'asyncio \\',
- 'LINKCC': 'clang',
+ 'LINKCC': 'x86_64-pc-linux-gnu-gcc',
  'LINKFORSHARED': '-Xlinker -export-dynamic',
  'LINK_PYTHON_DEPS': 'libpython3.11.so libpython3.so',
  'LINK_PYTHON_OBJS': '-L. -lpython3.11',
  'LIPO_32BIT_FLAGS': '',
  'LIPO_INTEL64_FLAGS': '',
  'LLVM_PROF_ERR': 'no',
- 'LLVM_PROF_FILE': 'LLVM_PROFILE_FILE="code-%p.profclangr"',
- 'LLVM_PROF_MERGER': '/usr/lib/llvm/17/bin/llvm-profdata merge '
-                     '-output=code.profclangd *.profclangr',
+ 'LLVM_PROF_FILE': '',
+ 'LLVM_PROF_MERGER': 'true',
  'LN': 'ln',
  'LOCALMODLIBS': '',
  'MACHDEP': 'linux',
  'MACHDEP_OBJS': '',
  'MACHDESTLIB': '/usr/lib/python3.11',
  'MACOSX_DEPLOYMENT_TARGET': '',
- 'MAINCC': 'clang',
+ 'MAINCC': 'x86_64-pc-linux-gnu-gcc',
  'MAJOR_IN_MKDEV': 0,
  'MAJOR_IN_SYSMACROS': 1,
  'MAKESETUP': './Modules/makesetup',
  'MANDIR': '/usr/share/man',
- 'MKDIR_P': '/bin/mkdir -p',
+ 'MKDIR_P': '/usr/bin/mkdir -p',
  'MODBUILT_NAMES': 'atexit  faulthandler  posix  _signal  _tracemalloc  '
                    '_codecs  _collections  errno  _io  itertools  _sre  '
                    '_thread  time  _weakref  _abc  _functools  _locale  '
@@ -822,7 +806,7 @@ build_time_vars = {'ABIFLAGS': '',
  'MODULE__CURSES_STATE': 'yes',
  'MODULE__DATETIME_LDFLAGS': '-lm',
  'MODULE__DATETIME_STATE': 'yes',
- 'MODULE__DBM_STATE': 'disabled',
+ 'MODULE__DBM_STATE': 'yes',
  'MODULE__DECIMAL_CFLAGS': '-I./Modules/_decimal/libmpdec -DCONFIG_64=1 '
                            '-DANSI=1 -DHAVE_UINT128_T=1',
  'MODULE__DECIMAL_DEPS': './Modules/_decimal/docstrings.h \\ '
@@ -833,7 +817,9 @@ build_time_vars = {'ABIFLAGS': '',
  'MODULE__ELEMENTTREE_DEPS': './Modules/pyexpat.c',
  'MODULE__ELEMENTTREE_STATE': 'yes',
  'MODULE__FUNCTOOLS_LDFLAGS': '',
- 'MODULE__GDBM_STATE': 'disabled',
+ 'MODULE__GDBM_CFLAGS': '',
+ 'MODULE__GDBM_LDFLAGS': '-lgdbm',
+ 'MODULE__GDBM_STATE': 'yes',
  'MODULE__HASHLIB_CFLAGS': '',
  'MODULE__HASHLIB_DEPS': './Modules/hashlib.h',
  'MODULE__HASHLIB_LDFLAGS': '-lcrypto',
@@ -938,15 +924,12 @@ build_time_vars = {'ABIFLAGS': '',
  'PARSER_OBJS': '\\ \\ Parser/myreadline.o Parser/tokenizer.o',
  'PEGEN_HEADERS': '\\',
  'PEGEN_OBJS': '\\',
- 'PGO_PROF_GEN_FLAG': '-fprofile-instr-generate',
- 'PGO_PROF_USE_FLAG': '-fprofile-instr-use=code.profclangd',
+ 'PGO_PROF_GEN_FLAG': '-fprofile-generate',
+ 'PGO_PROF_USE_FLAG': '-fprofile-use -fprofile-correction',
  'PLATLIBDIR': 'lib',
  'POBJS': '\\',
  'POSIX_SEMAPHORES_NOT_ENABLED': 0,
- 'PROFILE_TASK': '-m test -j24 --pgo-extended -u-network --timeout 1200 -x '
-                 'test_gdb -x test_dtrace -x test_asyncio -x test_httpservers '
-                 '-x test_logging -x test_multiprocessing_fork -x test_socket '
-                 '-x test_xmlrpc -x test_tools',
+ 'PROFILE_TASK': '-m test --pgo --timeout=1200',
  'PTHREAD_KEY_T_IS_COMPATIBLE_WITH_INT': 1,
  'PTHREAD_SYSTEM_SCHED_SUPPORTED': 1,
  'PURIFY': '',
@@ -965,69 +948,51 @@ build_time_vars = {'ABIFLAGS': '',
  'PYTHON_HEADERS': '\\',
  'PYTHON_OBJS': '\\',
  'PY_BUILTIN_HASHLIB_HASHES': '"md5,sha1,sha256,sha512,sha3,blake2"',
- 'PY_BUILTIN_MODULE_CFLAGS': '-Wsign-compare -Wunreachable-code -DNDEBUG -O3 '
-                             '-pipe -march=znver2 -mtune=znver3 -fpermissive '
-                             '-frecord-gcc-switches -fdiagnostics-color=never '
-                             '-Wno-error=implicit-function-declaration '
-                             '-flto=thin -Wno-cflagsver0010 -fwrapv -flto -g '
-                             '-std=c11 -Wextra -Wno-unused-parameter '
+ 'PY_BUILTIN_MODULE_CFLAGS': '-Wsign-compare -DNDEBUG -O3 -pipe -march=znver2 '
+                             '-mtune=znver3 -frecord-gcc-switches '
+                             '-fdiagnostics-color=never -fwrapv -std=c11 '
+                             '-Wextra -Wno-unused-parameter '
                              '-Wno-missing-field-initializers '
                              '-Wstrict-prototypes '
                              '-Werror=implicit-function-declaration '
-                             '-fvisibility=hidden '
-                             '-fprofile-instr-use=code.profclangd '
-                             '-I./Include/internal -I. -I./Include '
-                             '-I/usr/include/ncursesw -fPIC '
+                             '-fvisibility=hidden  -I./Include/internal -I. '
+                             '-I./Include -I/usr/include/ncursesw -fPIC '
                              '-DPy_BUILD_CORE_BUILTIN',
- 'PY_CFLAGS': '-Wsign-compare -Wunreachable-code -DNDEBUG',
- 'PY_CFLAGS_NODIST': '-O3 -pipe -march=znver2 -mtune=znver3 -fpermissive '
-                     '-frecord-gcc-switches -fdiagnostics-color=never '
-                     '-Wno-error=implicit-function-declaration -flto=thin '
-                     '-Wno-cflagsver0010 -fwrapv -flto -g -std=c11 -Wextra '
-                     '-Wno-unused-parameter -Wno-missing-field-initializers '
-                     '-Wstrict-prototypes '
+ 'PY_CFLAGS': '-Wsign-compare -DNDEBUG',
+ 'PY_CFLAGS_NODIST': '-O3 -pipe -march=znver2 -mtune=znver3 '
+                     '-frecord-gcc-switches -fdiagnostics-color=never -fwrapv '
+                     '-std=c11 -Wextra -Wno-unused-parameter '
+                     '-Wno-missing-field-initializers -Wstrict-prototypes '
                      '-Werror=implicit-function-declaration '
-                     '-fvisibility=hidden -fprofile-instr-use=code.profclangd '
-                     '-I./Include/internal',
+                     '-fvisibility=hidden  -I./Include/internal',
  'PY_COERCE_C_LOCALE': 1,
- 'PY_CORE_CFLAGS': '-Wsign-compare -Wunreachable-code -DNDEBUG -O3 -pipe '
-                   '-march=znver2 -mtune=znver3 -fpermissive '
-                   '-frecord-gcc-switches -fdiagnostics-color=never '
-                   '-Wno-error=implicit-function-declaration -flto=thin '
-                   '-Wno-cflagsver0010 -fwrapv -flto -g -std=c11 -Wextra '
+ 'PY_CORE_CFLAGS': '-Wsign-compare -DNDEBUG -O3 -pipe -march=znver2 '
+                   '-mtune=znver3 -frecord-gcc-switches '
+                   '-fdiagnostics-color=never -fwrapv -std=c11 -Wextra '
                    '-Wno-unused-parameter -Wno-missing-field-initializers '
                    '-Wstrict-prototypes -Werror=implicit-function-declaration '
-                   '-fvisibility=hidden -fprofile-instr-use=code.profclangd '
-                   '-I./Include/internal -I. -I./Include '
+                   '-fvisibility=hidden  -I./Include/internal -I. -I./Include '
                    '-I/usr/include/ncursesw -fPIC -DPy_BUILD_CORE',
- 'PY_CORE_LDFLAGS': '-v -Wl,-O1 -Wl,--as-needed -Wl,--as-needed -Wl,-O2 '
-                    '-Wl,--as-needed -Wl,-z,pack-relative-relocs -Wl,-z,relro '
-                    '-Wl,-z,now -flto -g',
+ 'PY_CORE_LDFLAGS': '-Wl,-O1 -Wl,--as-needed -Wl,-z,pack-relative-relocs',
  'PY_CPPFLAGS': '-I. -I./Include -I/usr/include/ncursesw',
  'PY_ENABLE_SHARED': 1,
  'PY_FORMAT_SIZE_T': '"z"',
  'PY_LDFLAGS': '',
- 'PY_LDFLAGS_NODIST': '-v -Wl,-O1 -Wl,--as-needed -Wl,--as-needed -Wl,-O2 '
-                      '-Wl,--as-needed -Wl,-z,pack-relative-relocs '
-                      '-Wl,-z,relro -Wl,-z,now -flto -g',
- 'PY_LDFLAGS_NOLTO': '-flto=thin',
+ 'PY_LDFLAGS_NODIST': '-Wl,-O1 -Wl,--as-needed -Wl,-z,pack-relative-relocs',
+ 'PY_LDFLAGS_NOLTO': '',
  'PY_SQLITE_ENABLE_LOAD_EXTENSION': 1,
  'PY_SQLITE_HAVE_SERIALIZE': 1,
  'PY_SSL_DEFAULT_CIPHERS': 1,
  'PY_SSL_DEFAULT_CIPHER_STRING': 0,
- 'PY_STDMODULE_CFLAGS': '-Wsign-compare -Wunreachable-code -DNDEBUG -O3 -pipe '
-                        '-march=znver2 -mtune=znver3 -fpermissive '
-                        '-frecord-gcc-switches -fdiagnostics-color=never '
-                        '-Wno-error=implicit-function-declaration -flto=thin '
-                        '-Wno-cflagsver0010 -fwrapv -flto -g -std=c11 -Wextra '
+ 'PY_STDMODULE_CFLAGS': '-Wsign-compare -DNDEBUG -O3 -pipe -march=znver2 '
+                        '-mtune=znver3 -frecord-gcc-switches '
+                        '-fdiagnostics-color=never -fwrapv -std=c11 -Wextra '
                         '-Wno-unused-parameter -Wno-missing-field-initializers '
                         '-Wstrict-prototypes '
                         '-Werror=implicit-function-declaration '
-                        '-fvisibility=hidden '
-                        '-fprofile-instr-use=code.profclangd '
-                        '-I./Include/internal -I. -I./Include '
-                        '-I/usr/include/ncursesw -fPIC',
- 'PY_SUPPORT_TIER': 2,
+                        '-fvisibility=hidden  -I./Include/internal -I. '
+                        '-I./Include -I/usr/include/ncursesw -fPIC',
+ 'PY_SUPPORT_TIER': 1,
  'Py_DEBUG': 0,
  'Py_ENABLE_SHARED': 1,
  'Py_HASH_ALGORITHM': 0,
@@ -1035,10 +1000,10 @@ build_time_vars = {'ABIFLAGS': '',
  'Py_SUNOS_VERSION': 0,
  'Py_TRACE_REFS': 0,
  'QUICKTESTOPTS': '-x test_subprocess test_io test_lib2to3 \\',
- 'READELF': 'llvm-readelf',
+ 'READELF': 'x86_64-pc-linux-gnu-readelf',
  'RESSRCDIR': 'Mac/Resources/framework',
  'RETSIGTYPE': 'void',
- 'RUNSHARED': 'LD_LIBRARY_PATH=/var/tmp/portage/dev-lang/python-3.11.7/work/Python-3.11.7',
+ 'RUNSHARED': 'LD_LIBRARY_PATH=/var/tmp/portage/dev-lang/python-3.11.8/work/Python-3.11.8',
  'SCRIPTDIR': '/usr/lib',
  'SETPGRP_HAVE_ARG': 0,
  'SHELL': '/bin/sh',
@@ -1082,10 +1047,10 @@ build_time_vars = {'ABIFLAGS': '',
  'SYS_SELECT_WITH_SYS_TIME': 1,
  'TESTOPTS': '',
  'TESTPATH': '',
- 'TESTPYTHON': 'LD_LIBRARY_PATH=/var/tmp/portage/dev-lang/python-3.11.7/work/Python-3.11.7 '
+ 'TESTPYTHON': 'LD_LIBRARY_PATH=/var/tmp/portage/dev-lang/python-3.11.8/work/Python-3.11.8 '
                './python -E',
  'TESTPYTHONOPTS': '',
- 'TESTRUNNER': 'LD_LIBRARY_PATH=/var/tmp/portage/dev-lang/python-3.11.7/work/Python-3.11.7 '
+ 'TESTRUNNER': 'LD_LIBRARY_PATH=/var/tmp/portage/dev-lang/python-3.11.8/work/Python-3.11.8 '
                './python -E ./Tools/scripts/run_tests.py',
  'TESTSUBDIRS': 'ctypes/test \\',
  'TESTTIMEOUT': 1200,
@@ -1116,8 +1081,8 @@ build_time_vars = {'ABIFLAGS': '',
  'WITH_VALGRIND': 0,
  'X87_DOUBLE_ROUNDING': 0,
  'XMLLIBSUBDIRS': 'xml xml/dom xml/etree xml/parsers xml/sax',
- 'abs_builddir': '/var/tmp/portage/dev-lang/python-3.11.7/work/Python-3.11.7',
- 'abs_srcdir': '/var/tmp/portage/dev-lang/python-3.11.7/work/Python-3.11.7',
+ 'abs_builddir': '/var/tmp/portage/dev-lang/python-3.11.8/work/Python-3.11.8',
+ 'abs_srcdir': '/var/tmp/portage/dev-lang/python-3.11.8/work/Python-3.11.8',
  'datarootdir': '/usr/share',
  'exec_prefix': '/usr',
  'prefix': '/usr',
